@@ -105,6 +105,10 @@ class WMIException(OSWinException):
         super(WMIException, self).__init__(message)
 
 
+class WqlException(OSWinException):
+    pass
+
+
 class ISCSITargetException(OSWinException):
     pass
 
@@ -128,3 +132,7 @@ class Win32IOException(Win32Exception):
 
 class DiskNotFound(NotFound):
     pass
+
+
+class HyperVRemoteFXException(HyperVException):
+    pass
